Crate block_graph Copy item path Source builtin builtin ai layers and value types burn ai layers and value types relating to the burn library ops operator like traits for common tensor operations ConnectionEditor allows configuring a connection to add to the graph, or manipulating an existing connection ConnectionInfo information about a connection Extendable wraps collections so that merging concatenates them using the Extend trait Graph graph like ai operation structure Inner wraps an inner value so it can be unwrapped with unwrap inner Label label for graph connections or layers or nodes. format is id: name where id is a hex number or simply id if there is no name. name without a number will be parse as a name with a 0 id Unvec wraps the graph so it can take singular io AI general ai trait Decompose trait to decompose AI modules into components that implement other libraries’ traits IntoSequence conversion from a composite module into a sequential list of modules Merge trait to allow merging multiple outputs into one graph node Op composition trait UnwrapInner trait for unwrapping nested wrapped values