pub struct LogSoftmaxLayer { /* private fields */ }Expand description
layer to apply an operation
Implementations
Sourceimpl LogSoftmaxLayer
impl LogSoftmaxLayer
Sourcepub fn get_temperature(&self) -> f32
pub fn get_temperature(&self) -> f32
gets the temperature
Sourcepub fn set_temperature(&mut self, temperature: f32)
pub fn set_temperature(&mut self, temperature: f32)
sets the mismatch behavior. A temperature of NaN will make the non soft version if possible. A finite temperature will make the soft version
Sourcepub fn with_temperature(self, temperature: f32) -> Self
pub fn with_temperature(self, temperature: f32) -> Self
sets the temperature. A temperature of NaN will make the non soft version if possible. A finite temperature will make the soft version