pub struct Duplicate<A> { /* private fields */ }Expand description
module for cloning things
Implementations
Sourceimpl<A> Duplicate<A>
impl<A> Duplicate<A>
Sourcepub fn into_inner(self) -> A
pub fn into_inner(self) -> A
returns the inner value
Sourcepub fn from_inner(inner: A) -> Self
pub fn from_inner(inner: A) -> Self
creates a new duplicate module from the inner value
Sourcepub fn with_inner<B>(&self, inner: B) -> Duplicate<B>
pub fn with_inner<B>(&self, inner: B) -> Duplicate<B>
replaces the inner value
Sourcepub fn with_times(self, times: usize) -> Self
pub fn with_times(self, times: usize) -> Self
sets the suggested number of times to duplicate for a variable sized output like a vec. fixed array outputs of other lengths will still be allowed