Module burn

Module burn 

ai layers and value types relating to the burn library

Re-exports

pub use burn as lib;

Structs

Attention
layer for computing attention from [key,query,value] inputs
AttentionConfig
layer for computing attention from [key,query,value] inputs
BatchStacker
batcher that stacks things
BiasConfig
layer for adding bias somewhere
Cache
layer for caching kv values from kqv when run mutably. cats along d1 and outputs the concatenated keys and values.
Classification
wrapper for converting loss to classification output
ClassificationLayer
layer for converting loss to classification output
DontRender
metrics renderer implementation that doesn’t actually do anything
Identity
identity version that knows what backend
KQV
layer for linear splitting into [key,query,value] for attention purposes
KQVConfig
layer for linear splitting into [key,query,value] for attention purposes
LossOutput
general loss output for being converted into other loss outputs
PowerMaskInfo
power mask information
Regression
wrapper for converting loss to regression output
RegressionLayer
layer for converting loss to regression output
TrainConfig
configuration for convenient training through the wrapper
Wrapped
wraps in a burn wrapper

Enums

AttentionMask
Config
enumerates config for some burn layers
Kind
enumerates kinds for values
Layer
enumerates some burn layers
Reshape
value reshaping arguments
Shape
tensor shapes for Value
Value
enumerates burn tensors up to 8 dimensions, along with a variant to represent operation compatibility errors, and a variant for multiple tensors. An empty multi variant can be used to represent a lack of data. Once a the depth of a multi variant is enough for an operation to take full effect, further nesting should result in the same as applying separately

Traits

Shortcuts
chained method shortcut trait
ToBackend
trait for switching the backend of a module
Wrappable
higher kinded type trait to allow rewrapping burn modules in different backends to implement some wrapper features

Functions

apply_depthwise
helper function for applying operations that apply to a specific depth of multiple structure such that wrapping multiple appropriate inputs with a multi outputs the output of the function applied to all inputs. 0 depth for empty, 1 for single, 2+ for multi
new
starts the building of an ai structure in chained method style from an identity operation