Reshape

Enum Reshape 

pub enum Reshape {
    R1([isize; 1]),
    R2([isize; 2]),
    R3([isize; 3]),
    R4([isize; 4]),
    R5([isize; 5]),
    R6([isize; 6]),
    R7([isize; 7]),
    R8([isize; 8]),
    Recursive(Vec<Reshape>),
}
value reshaping arguments

Variants



R1([isize; 1])



R2([isize; 2])



R3([isize; 3])



R4([isize; 4])



R5([isize; 5])



R6([isize; 6])



R7([isize; 7])



R8([isize; 8])



Recursive(Vec<Reshape>)

Implementations

Source

impl Reshape

pub fn depth(&self) -> usize

counts the recursive depth

pub fn to_array(self, alignment: Alignment) -> [isize; 8]

converts to the eight dimensional array type by extending with ones. The original data will be placed according to the alignment. Multi and incompatible types will be all ones