Shape

Enum Shape 

pub enum Shape {
    Incompatible(String),
    Multi(usize),
    Recursive(Vec<Shape>),
    X1([usize; 1]),
    X2([usize; 2]),
    X3([usize; 3]),
    X4([usize; 4]),
    X5([usize; 5]),
    X6([usize; 6]),
    X7([usize; 7]),
    X8([usize; 8]),
}
tensor shapes for Value

Variants



Incompatible(String)



Multi(usize)



Recursive(Vec<Shape>)



X1([usize; 1])



X2([usize; 2])



X3([usize; 3])



X4([usize; 4])



X5([usize; 5])



X6([usize; 6])



X7([usize; 7])



X8([usize; 8])

Implementations

Source

impl Shape

pub fn count(&self) -> Option<usize>

counts the number of components if possible. returns none if incompatible or if a non recursive multi shape of more than 0 tensors

pub fn to_array(self, alignment: Alignment) -> [usize; 8]

converts to the eight dimensional array type by extending with ones. The original data will be placed according to the alignment. Multi and incompatible types will be all ones