Value

Enum Value 

pub enum Value<B: Backend> {
Show 26 variants B1(Tensor<B, 1, Bool>), B2(Tensor<B, 2, Bool>), B3(Tensor<B, 3, Bool>), B4(Tensor<B, 4, Bool>), B5(Tensor<B, 5, Bool>), B6(Tensor<B, 6, Bool>), B7(Tensor<B, 7, Bool>), B8(Tensor<B, 8, Bool>), F1(Tensor<B, 1, Float>), F2(Tensor<B, 2, Float>), F3(Tensor<B, 3, Float>), F4(Tensor<B, 4, Float>), F5(Tensor<B, 5, Float>), F6(Tensor<B, 6, Float>), F7(Tensor<B, 7, Float>), F8(Tensor<B, 8, Float>), I1(Tensor<B, 1, Int>), I2(Tensor<B, 2, Int>), I3(Tensor<B, 3, Int>), I4(Tensor<B, 4, Int>), I5(Tensor<B, 5, Int>), I6(Tensor<B, 6, Int>), I7(Tensor<B, 7, Int>), I8(Tensor<B, 8, Int>), Incompatible(String), Multi(Vec<Self>),
}
enumerates burn tensors up to 8 dimensions, along with a variant to represent operation compatibility errors, and a variant for multiple tensors. An empty multi variant can be used to represent a lack of data. Once a the depth of a multi variant is enough for an operation to take full effect, further nesting should result in the same as applying separately

Variants



B1(Tensor<B, 1, Bool>)



B2(Tensor<B, 2, Bool>)



B3(Tensor<B, 3, Bool>)



B4(Tensor<B, 4, Bool>)



B5(Tensor<B, 5, Bool>)



B6(Tensor<B, 6, Bool>)



B7(Tensor<B, 7, Bool>)



B8(Tensor<B, 8, Bool>)



F1(Tensor<B, 1, Float>)



F2(Tensor<B, 2, Float>)



F3(Tensor<B, 3, Float>)



F4(Tensor<B, 4, Float>)



F5(Tensor<B, 5, Float>)



F6(Tensor<B, 6, Float>)



F7(Tensor<B, 7, Float>)



F8(Tensor<B, 8, Float>)



I1(Tensor<B, 1, Int>)



I2(Tensor<B, 2, Int>)



I3(Tensor<B, 3, Int>)



I4(Tensor<B, 4, Int>)



I5(Tensor<B, 5, Int>)



I6(Tensor<B, 6, Int>)



I7(Tensor<B, 7, Int>)



I8(Tensor<B, 8, Int>)



Incompatible(String)



Multi(Vec<Self>)

Implementations

Source

impl<B: Backend> Value<B>

pub fn all(self) -> Value<B>

tests if all values are true

pub fn all_dim(self, d: i32) -> Value<B>

tests if all values are true along the dim

pub fn any(self) -> Value<B>

tests if any values are true

pub fn any_dim(self, d: i32) -> Value<B>

tests if any values are true along the dim

pub fn bool(self) -> Value<B>

casts to a bool tensor if not one

pub fn count(&self) -> usize

counts the number of components in the tensor

pub fn empty() -> Self

creates a new empty value

pub fn flatten_values(self) -> Self

flattens depth first into a list of tensors

pub fn float(self) -> Value<B>

casts to a float tensor if not one

pub fn from_values<I: IntoIterator<Item = Self>, S: Into<Shape>>( inner: I, shape: S, ) -> Self

creates a value from the inner values and recursive shape. Doesn’t check actual dimension values, the shape is just used for recursion data

pub fn gather(self, dim: i32, indices: Value<B>) -> Self

gather

pub fn int(self) -> Value<B>

casts to a int tensor if not one

pub fn into_float_vec(self) -> Vec<f32>

converts to a flattened vector of floats, ignoring incompatibility errors

pub fn into_int_vec(self) -> Vec<i32>

converts to a flattened vector of ints, ignoring incompatibility errors

pub fn height(&self) -> usize

returns the maximum recursive depth of the value tree (its height). Returns 0 for empty or single

pub fn is_empty(&self) -> bool

tests if the tensor is empty. incompatible isn’t considered empty for the purposes of this function

pub fn is_incompatible(&self) -> bool

tests if the tensor represents the result of an incompatible input and operation

pub fn into_multi(self) -> Vec<Value<B>>

converts to a multiple tensor, then unwraps to a vec of values

pub fn is_multi(&self) -> bool

tests if this is a multiple tensor. also returns true for empty and multi that only have one value

pub fn iter(&self) -> SliceIter<'_, Self>

shallow iteration over the contained values

pub fn kind(&self) -> Kind

returns the kind of value

pub fn len(&self) -> usize

returns a shallow count the number of values directly within this one. 1 if not multi, otherwise the len of the vec inside.

pub fn len_recursive(&self) -> usize

recursively counts the number of tensors within this value, including multi tensors within multi tensors

pub fn map_multi<F: FnMut(Value<B>) -> Value<B>>( self, depth: usize, f: F, ) -> Self

applies a function to each multi tensor value whose maximum distance to a leaf is depth. The depth for empty or single is 0, multi containing only empty or single is 1, etc

pub fn map_values<F: FnMut(Value<B>) -> Value<B>>(self, f: F) -> Self

applies a function to each single tensor value

pub fn mask_fill(self, mask: Value<B>, v: f32) -> Self

mask filling

pub fn multi(self) -> Self

casts to a multiple tensor if not one

pub fn new<S: Into<Shape>>(data: &[f32], device: &B::Device, shape: S) -> Self

creates a new multi tensor from the data and shape // TODO make work for bool and int too

pub fn promote(self, rhs: Value<B>) -> (Value<B>, Value<B>)

promotes the values to make them compatible if possible. bools can become floats or ints, ints can become floats, any can become multi, and lower ranks can be unsqueezed to higher ranks. This is a shallow operation, so tensors inside multi will be unaffected. incompatible with non multi will return the input

pub fn promote_kind(self, rhs: Value<B>) -> (Value<B>, Value<B>)

promotes the values to make them match if possible. bools can become floats or ints, ints can become floats, any can become multi. This is a shallow operation, so tensors inside multi will be unaffected. incompatible with non multi will return the input

pub fn promote_rank(self, rhs: Value<B>) -> (Value<B>, Value<B>)

promotes the values to make them match if possible. lower ranks can be unsqueezed to higher ranks. This is a shallow operation, so tensors inside multi will be unaffected. incompatible with non multi will return the input

pub fn rank(&self) -> Option<usize>

returns the number of axes of the tensor, or none if incompatible or multi

pub fn scatter(self, dim: i32, indices: Value<B>, values: Value<B>) -> Self

scatter

pub fn shape(&self) -> Shape

gets the shape of the tensor. Use the recursive version to recursively get the multi shape

pub fn shape_recursive(&self) -> Shape

gets the shape of the tensor. Use the non recusive function if deep shape structure of multi is not required

pub fn shift(self, d: i32, n: i32, v: f32) -> Self

shifts the components right n places, maintaining the current dimensions, filling the left spot with v cast to the appropriate type

pub fn slice<A: AsRef<[R]>, R: RangeBounds<usize>>(self, ranges: A) -> Self

returns a value containing the elements selected from the given ranges. If this is a multi tensor the slice will be applied to each sub tensor

pub fn split<I: Into<Option<i32>>>(self, chunksize: usize, dim: I) -> Self

splits into chunks along the dimension, or the multi vector if dim is None

pub fn squeeze(self) -> Self

squeeze 0

pub fn squeeze_dim(self, d: i32) -> Self

removes a dimension of size 1 at position d. incompatible if dimension at position d is not 1

pub fn try_incompatible(self) -> Result<String, Self>

attempts to unwrap the inner incompatible value

pub fn try_multi(self) -> Result<Vec<Value<B>>, Self>

attempts to unwrap the inner multi value

pub fn unsqueeze(self) -> Self

unsqueeze 0

pub fn unsqueeze_dim(self, d: i32) -> Self

inserts a dimension of size 1 at position d, or N+d+1 if d is negative

pub fn unwrap_incompatible(self) -> String

attempts to unwrap the inner incompatible value

pub fn unwrap_multi(self) -> Vec<Value<B>>

attempts to unwrap the inner multi value

pub fn zeros_like(&self) -> Value<B>

zeros like

pub fn zip(self) -> Self

takes in a multi value and zips the leaves of each inner value together. If this input is empty or single it is returned unchanged. Mistmatch between single and multi substructures will cause the multi to be interpreted as a leaf. Mismatch between multi lengths will cause the shorter to be extended with empty

pub fn try_b1(self) -> Result<Tensor<B, 1, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b1(self) -> Tensor<B, 1, Bool>

attempts to unwrap the inner value

pub fn try_b2(self) -> Result<Tensor<B, 2, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b2(self) -> Tensor<B, 2, Bool>

attempts to unwrap the inner value

pub fn try_b3(self) -> Result<Tensor<B, 3, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b3(self) -> Tensor<B, 3, Bool>

attempts to unwrap the inner value

pub fn try_b4(self) -> Result<Tensor<B, 4, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b4(self) -> Tensor<B, 4, Bool>

attempts to unwrap the inner value

pub fn try_b5(self) -> Result<Tensor<B, 5, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b5(self) -> Tensor<B, 5, Bool>

attempts to unwrap the inner value

pub fn try_b6(self) -> Result<Tensor<B, 6, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b6(self) -> Tensor<B, 6, Bool>

attempts to unwrap the inner value

pub fn try_b7(self) -> Result<Tensor<B, 7, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b7(self) -> Tensor<B, 7, Bool>

attempts to unwrap the inner value

pub fn try_b8(self) -> Result<Tensor<B, 8, Bool>, Self>

attempts to unwrap the inner value

pub fn unwrap_b8(self) -> Tensor<B, 8, Bool>

attempts to unwrap the inner value

pub fn try_f1(self) -> Result<Tensor<B, 1, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f1(self) -> Tensor<B, 1, Float>

attempts to unwrap the inner value

pub fn try_f2(self) -> Result<Tensor<B, 2, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f2(self) -> Tensor<B, 2, Float>

attempts to unwrap the inner value

pub fn try_f3(self) -> Result<Tensor<B, 3, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f3(self) -> Tensor<B, 3, Float>

attempts to unwrap the inner value

pub fn try_f4(self) -> Result<Tensor<B, 4, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f4(self) -> Tensor<B, 4, Float>

attempts to unwrap the inner value

pub fn try_f5(self) -> Result<Tensor<B, 5, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f5(self) -> Tensor<B, 5, Float>

attempts to unwrap the inner value

pub fn try_f6(self) -> Result<Tensor<B, 6, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f6(self) -> Tensor<B, 6, Float>

attempts to unwrap the inner value

pub fn try_f7(self) -> Result<Tensor<B, 7, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f7(self) -> Tensor<B, 7, Float>

attempts to unwrap the inner value

pub fn try_f8(self) -> Result<Tensor<B, 8, Float>, Self>

attempts to unwrap the inner value

pub fn unwrap_f8(self) -> Tensor<B, 8, Float>

attempts to unwrap the inner value

pub fn try_i1(self) -> Result<Tensor<B, 1, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i1(self) -> Tensor<B, 1, Int>

attempts to unwrap the inner value

pub fn try_i2(self) -> Result<Tensor<B, 2, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i2(self) -> Tensor<B, 2, Int>

attempts to unwrap the inner value

pub fn try_i3(self) -> Result<Tensor<B, 3, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i3(self) -> Tensor<B, 3, Int>

attempts to unwrap the inner value

pub fn try_i4(self) -> Result<Tensor<B, 4, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i4(self) -> Tensor<B, 4, Int>

attempts to unwrap the inner value

pub fn try_i5(self) -> Result<Tensor<B, 5, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i5(self) -> Tensor<B, 5, Int>

attempts to unwrap the inner value

pub fn try_i6(self) -> Result<Tensor<B, 6, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i6(self) -> Tensor<B, 6, Int>

attempts to unwrap the inner value

pub fn try_i7(self) -> Result<Tensor<B, 7, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i7(self) -> Tensor<B, 7, Int>

attempts to unwrap the inner value

pub fn try_i8(self) -> Result<Tensor<B, 8, Int>, Self>

attempts to unwrap the inner value

pub fn unwrap_i8(self) -> Tensor<B, 8, Int>

attempts to unwrap the inner value