pub fn apply_depthwise<B: Backend, F: Fn(Value<B>) -> Value<B>>(
depth: usize,
op: F,
value: Value<B>,
) -> Value<B>Expand description
helper function for applying operations that apply to a specific depth of multiple structure such that wrapping multiple appropriate inputs with a multi outputs the output of the function applied to all inputs.