ConnectionEditor

Struct ConnectionEditor 

pub struct ConnectionEditor<'a, C: AI<V, V> + Op<Output = V>, V: Clone + Default + Merge> { /* private fields */ }
allows configuring a connection to add to the graph, or manipulating an existing connection

Implementations

Source

impl<'a, C: AI<V, V> + Op<Output = V>, V: Clone + Default + Merge> ConnectionEditor<'a, C, V>

pub fn get_index(&self) -> usize

gets the index, or usize::MAX to insert at the end of the order regardless of the number of connections

pub fn input(&self) -> &Label

references the input label

pub fn insert_layer<L: Into<C>>(&mut self, layer: L) -> Option<C>

adds a layer to the associated graph if there is one, returning the layer if not or the previous layer associated with the layer id

pub fn is_clear(&self) -> bool

checks if clear

pub fn label(&self) -> &Label

references the connection label

pub fn layer(&self) -> &Label

references the layer label

pub fn output(&self) -> &Label

references the input label

pub fn with<L: Into<C>>(self, layer: L) -> Self

inserts the layer into the graph using the current layer id

pub fn with_clear(self, clear: bool) -> Self

sets the flag for whether the input should be cleared after use

pub fn with_index(self, index: usize) -> Self

sets the index to insert in the run order, or usize::MAX to insert at the end of the order regardless of the number of connections

pub fn with_input<L: Into<Label>>(self, label: L) -> Self

sets the input label

pub fn with_label<L: Into<Label>>(self, label: L) -> Self

sets the connection label

pub fn with_layer<L: Into<Label>>(self, label: L) -> Self

sets the layer label

pub fn with_output<L: Into<Label>>(self, label: L) -> Self

sets the output label