Graph

Struct Graph 

pub struct Graph<C> { /* private fields */ }
graph like ai operation structure

Implementations

Source

impl<C: AI<V, V> + Op<Output = V>, V: Clone + Default + Merge> Graph<C>

pub fn new() -> Self

creates a new empty graph

pub fn add_connection<'a>(&mut self, config: &ConnectionEditor<'a, C, V>)

adds a connection between two vertices

pub fn add_layer<X: Into<C>, L: Into<Label>>(&mut self, label: L, layer: X)

adds a layer without connecting it

pub fn connect<I: Into<Label>, O: Into<Label>>( &mut self, input: I, output: O, ) -> ConnectionEditor<'_, C, V>

adds a connection between vertices

pub fn connections<'a>( &'a self, ) -> impl Iterator<Item = ConnectionInfo<'a, C, V>>

returns an iterator over the connections in an arbitrary order

pub fn get_connection<'a>( &'a self, label: &Label, ) -> Option<ConnectionInfo<'a, C, V>>

gets connection information by label

pub fn get_layer(&self, label: &Label) -> Option<&C>

gets the layer information by label

pub fn merge<A: Into<C>>(&mut self, graph: Graph<A>)

another graphs into this one

pub fn order(&self) -> &[Label]

gets the connection order

pub fn split<F: FnMut(bool, &Label, &Label, &C, &Label, &Label) -> bool>( &mut self, predicate: F, ) -> Self
where C: Clone,

splits the graph according to the predicate(clear, connectionlabel, inputlabel, layer, layerlabel, outputlabel). true will be sent to the returned graph. the resulting graphs will only have the layers they use

pub fn sort(&mut self)

topologically sorts the graph. Inputs to the same node will retain their relative order.