pub struct Label { /* private fields */ }Expand description
label for graph connections or layers or nodes. format is id: name where id is a hex number or simply id if there is no name. name without a number will be parse as a name with a 0 id
Implementations