Merge

Trait Merge 

pub trait Merge {
    // Required method
    fn merge(&mut self, other: Self);
}
trait to allow merging multiple outputs into one graph node

Required Methods

fn merge(&mut self, other: Self)

merges the other into self, taking out of other if convenient

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<E> Merge for Vec<E>

Source

fn merge(&mut self, other: Self)

Source

impl<E: Merge> Merge for Option<E>

Source

fn merge(&mut self, other: Self)

Implementors

Source

impl<B: Backend> Merge for Value<B>

Source

impl<E, V: Extend<E> + IntoIterator<Item = E>> Merge for Extendable<V>