Module builtin

Module builtin 

builtin ai layers and value types

Modules

math
layers representing important mathematical operations
reinforcement
layers relating to reinforcement learning
soft
layers relating to cross entropy or softmax
structural
layers like cat or swap dims that change the organization or structure of tensors

Structs

Apply
applies a closure to the input// TODO more closure layers maybe
Autoregression
autoregressive inference
Duplicate
module for cloning things
Map
wraps to apply to every element of a vector
Residual
layer to add an optional residual connection
Sequential
wrapper for applying ai modules sequentially
SetType
fixes the output type of a layer for a particular input type.
SqueezeLayer
layer for removing dimensions with size 1
Zip
wraps to apply each function

Enums

Alignment
alignment
OnMismatch
shape mismatch handling
ReductionMode
reduction mode

Functions

apply
creates an operation that applies the closure