pub trait Wrappable:
Clone
+ Debug
+ Decompose
+ Send {
type B: Backend;
type With<C: Backend>: Wrappable<B = C, With<C> = Self::With<C>> + Wrappable<B = C, With<Self::B> = Self>;
}Expand description
higher kinded type trait to allow rewrapping burn modules in different backends to implement some wrapper features
Required Associated Types
type B: Backend
type With<C: Backend>: Wrappable<B = C, With<C> = Self::With<C>> + Wrappable<B = C, With<Self::B> = Self>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.