pub struct Graph<C> { /* private fields */ }Expand description
graph like ai operation structure
Implementations
Sourceimpl<C: AI<V, V> + Op<Output = V>, V: Clone + Default + Merge> Graph<C>
impl<C: AI<V, V> + Op<Output = V>, V: Clone + Default + Merge> Graph<C>
Sourcepub fn add_connection<'a>(&mut self, config: &ConnectionEditor<'a, C, V>)
pub fn add_connection<'a>(&mut self, config: &ConnectionEditor<'a, C, V>)
adds a connection between two vertices
Sourcepub fn add_layer<X: Into<C>, L: Into<Label>>(&mut self, label: L, layer: X)
pub fn add_layer<X: Into<C>, L: Into<Label>>(&mut self, label: L, layer: X)
adds a layer without connecting it
Sourcepub fn connect<I: Into<Label>, O: Into<Label>>(
&mut self,
input: I,
output: O,
) -> ConnectionEditor<'_, C, V>
pub fn connect<I: Into<Label>, O: Into<Label>>( &mut self, input: I, output: O, ) -> ConnectionEditor<'_, C, V>
adds a connection between vertices
Sourcepub fn connections<'a>(
&'a self,
) -> impl Iterator<Item = ConnectionInfo<'a, C, V>>
pub fn connections<'a>( &'a self, ) -> impl Iterator<Item = ConnectionInfo<'a, C, V>>
returns an iterator over the connections in an arbitrary order
Sourcepub fn get_connection<'a>(
&'a self,
label: &Label,
) -> Option<ConnectionInfo<'a, C, V>>
pub fn get_connection<'a>( &'a self, label: &Label, ) -> Option<ConnectionInfo<'a, C, V>>
gets connection information by label
Sourcepub fn split<F: FnMut(bool, &Label, &Label, &C, &Label, &Label) -> bool>(
&mut self,
predicate: F,
) -> Selfwhere
C: Clone,
pub fn split<F: FnMut(bool, &Label, &Label, &C, &Label, &Label) -> bool>(
&mut self,
predicate: F,
) -> Selfwhere
C: Clone,
splits the graph according to the predicate(clear, connectionlabel, inputlabel, layer, layerlabel, outputlabel). true will be sent to the returned graph. the resulting graphs will only have the layers they use